@@ -5,6 +5,9 @@ Bugout knowledge bases.
 import atexit
 import concurrent.futures
 from dataclasses import dataclass, field
+from enum import Enum
+import os
+import pkg_resources
 import textwrap
 import time
 import traceback
@@ -27,6 +30,11 @@ class Report:
     tags: List[str] = field(default_factory=list)
 
 
+class Modes(Enum):
+    DEFAULT = 0
+    SYNCHRONOUS = 1
+
+
 class Reporter:
     def __init__(
         self,
@@ -38,6 +46,7 @@ class Reporter:
         bugout_token: Optional[str] = None,
         bugout_journal_id: Optional[str] = None,
         timeout_seconds: int = 10,
+        mode: Modes = Modes.DEFAULT,
     ):
         self.name = name
         self.consent = consent
@@ -54,16 +63,21 @@ class Reporter:
         self.bugout_journal_id = bugout_journal_id
         self.timeout_seconds = timeout_seconds
 
-        self.executor = concurrent.futures.ThreadPoolExecutor(
-            max_workers=1, thread_name_prefix="humbug_reporter"
-        )
         self.report_futures: List[concurrent.futures.Future] = []
         atexit.register(self.wait)
 
+        self.executor: Optional[concurrent.futures.Executor] = None
+        if mode == Modes.DEFAULT:
+            self.executor = concurrent.futures.ThreadPoolExecutor(
+                max_workers=1, thread_name_prefix="humbug_reporter"
+            )
+
     def wait(self) -> None:
         concurrent.futures.wait(
             self.report_futures, timeout=float(self.timeout_seconds)
         )
+        if self.executor is not None:
+            self.executor.shutdown()
 
     def system_tags(self) -> List[str]:
         tags = [
@@ -92,7 +106,7 @@ class Reporter:
 
         try:
             report.tags = list(set(report.tags))
-            if wait:
+            if wait or self.executor is None:
                 self.bugout.create_entry(
                     token=self.bugout_token,
                     journal_id=self.bugout_journal_id,
@@ -225,6 +239,55 @@ class Reporter:
 
         return report
 
+    def env_report(
+        self,
+        title: Optional[str] = None,
+        tags: Optional[List[str]] = None,
+        publish: bool = True,
+        wait: bool = False,
+    ) -> Report:
+        """
+        Creates and optionally publishes a report containing the environment variables defined in
+        the current process.
+        """
+        if title is None:
+            title = "Environment variables"
+        if tags is None:
+            tags = []
+
+        env_vars = ["{}={}".format(key, value) for key, value in os.environ.items()]
+        content = "```\n{}\n```".format("\n".join(env_vars))
+
+        report = Report(title=title, content=content, tags=tags)
+        if publish:
+            self.publish(report, wait=wait)
+        return report
+
+    def packages_report(
+        self,
+        title: Optional[str] = None,
+        tags: Optional[List[str]] = None,
+        publish: bool = True,
+        wait: bool = False,
+    ) -> Report:
+        """
+        Creates and optionally publishes a report containing the packages (and versions of those
+        packages) available in the current Python process.
+        """
+        if title is None:
+            title = "Available packages"
+        if tags is None:
+            tags = []
+
+        available_packages = [
+            str(package_info) for package_info in pkg_resources.working_set
+        ]
+        content = "```\n{}\n```".format("\n".join(available_packages))
+        report = Report(title, content, tags)
+        if publish:
+            self.publish(report, wait=wait)
+        return report
+
     def compound_report(
         self,
         reports: List[Report],
